/*
 * Complex
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

/**
 * The Complex class models a complex number.  It provides the operations
 * addition to a Complex, multiplication by a Complex factor, the square of a
 * Complex and the square of the absolute value of a Complex.
 * 
 * @author both
 */
public class Complex {
    /** The Complex's real part. */ 
    public double re;
    
    /** The Complex's imaginary part. */
    public double im;

    /**
     * Constructs a new Complex from two doubles.
     * 
     * @param re the real part of the Complex
     * @param im the imaginary part of the Complex
     */
    public Complex(double re, double im) {
        this.re = re;
        this.im = im;
    }

    /**
     * Constructs a new Complex from a given Complex.
     * 
     * @param c the given Complex
     */
    public Complex(Complex c) {
        this(c.re, c.im);
    }

    /**
     * Increments this complex number.
     * 
     * @param increment the increment to add to this
     */
    public void addTo(Complex increment) {
        this.re += increment.re;
        this.im += increment.im;
    }

    /**
     * Multiplies this complex number by another.
     * 
     * @param factor the factor to multiply this complex number by
     */
    public void multiplyBy(Complex factor) {
        if (factor == this) {
            this.square();
            return;
        }
        double re = this.re;
        this.re = re * factor.re - this.im * factor.im;
        this.im = re * factor.im + this.im * factor.re;
    }

    /**
     * Squares this complex number.
     */
    public void square() {
        double re = this.re;
        this.re = re * re - this.im * this.im;
        this.im = re * this.im * 2;
    }

    /**
     * Calculates the square of this complex number's absolute value.
     * This method is provided to avoid costly sqrt calulations.
     * 
     * @return the square of this complex number's absolute value
     */
    public double getAbsSquare() {
        return this.re * this.re + this.im * this.im; 
    }
}
