/*
 * DiscreteColorizer
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * Copyleft
 */
package infpp.fractal;

import java.awt.Color;

/**
 * The DiscreteColorizer class is the simplest implementation of the Colorizer
 * interface.
 * 
 * @author both
 */
public final class DiscreteColorizer implements Colorizer {
    int   maxIterations;
    Color convergenceColor;
    Color divergenceColor;

    /**
     * Constructs a new DiscreteColorizer using the colors black and white.
     * 
     * @param maxIterations the specified maximum number of iterations
     */
    public DiscreteColorizer(int maxIterations) {
        this(maxIterations, Color.WHITE, Color.BLACK);
    }

    /**
     * Constructs a new DiscreteColorizer using the specified colors.
     *
     * @param maxIterations    the specified maximum number of iterations
     * @param convergenceColor the color to be used whenever the number of
     *                         required iterations indicates convergence
     * @param divergenceColor  the color to be used whenever the number of
     *                         required iterations indicates divergence
     */
    public DiscreteColorizer(int maxIterations, Color convergenceColor,
	    Color divergenceColor) {
	this.maxIterations = maxIterations;
        this.convergenceColor = convergenceColor;
        this.divergenceColor = divergenceColor;
    }

    /**
     * Returns convergenceColor or divergenceColor depending on the given number of
     * required iterations.
     * 
     * @param  numberOfIterations the given number of required iterations
     * @return the calculated Color
     * @see    Colorizer#calculateColor(int)
     */
    @Override
    public Color calculateColor(int numberOfIterations) {
        return (numberOfIterations == maxIterations) // try comparing this to different low integers
                ? this.convergenceColor : this.divergenceColor;
    }
}
