/*
 * DoublePrecisionFractalGenerator
 * 
 * Version 0.2alpha
 * 
 * 2010-07-11
 * 
 * CopyLeft
 */
package infpp.fractal;

/**
 * The DoublePrecisionFractalGenerator class provides an abstract class that
 * serves as a common base for FractalGenerators using double precision
 * floating point arithmetic.
 * 
 * @author both
 */
public abstract class DoublePrecisionFractalGenerator
        implements FractalGenerator {
    private Complex complexOrigin = new Complex(0, 0);
    private double  realDimension = 4;
    private int     screenWidth;
    private int     screenHeight;
    private double  screenToRealFactor;
    private int     halfScreenWidth; // optimization, TODO: check if necessary
    private int     halfScreenHeight;

    /**
     * @see FractalGenerator#getComplexOrigin()
     */
    @Override
    public Complex getComplexOrigin() {
        return this.complexOrigin;
    }

    /**
     * @see FractalGenerator#setComplexOrigin(Complex)
     */
    @Override
    public void setComplexOrigin(Complex complexOrigin) {
        this.complexOrigin = complexOrigin;
    }

    /**
     * @see FractalGenerator#getRealDimension()
     */
    @Override
    public double getRealDimension() {
        return this.realDimension;
    }

    /**
     * @see FractalGenerator#setRealDimension(double)
     */
    @Override
    public void setRealDimension(double realDimension) {
        this.realDimension = realDimension;
        this.calculateScreenToRealFactor();
    }

    /**
     * @see FractalGenerator#getScreenWidth()
     */
    @Override
    public int getScreenWidth() {
        return this.screenWidth;
    }

    /**
     * @see FractalGenerator#getScreenHeight()
     */
    @Override
    public int getScreenHeight() {
        return this.screenHeight;
    }

    /**
     * @see FractalGenerator#setScreenDimension(int, int)
     */
    @Override
    public void setScreenDimension(int width, int height) {
        this.screenWidth = width;
        this.screenHeight = height;
        this.halfScreenWidth = width / 2;
        this.halfScreenHeight = height / 2;
        this.calculateScreenToRealFactor();
    }

    /**
     * @see FractalGenerator#calculateComplexFromScreenCoordinates(int, int)
     */
    @Override
    public Complex calculateComplexFromScreenCoordinates(int x, int y) {
        return new Complex(
                (x - this.halfScreenWidth) * this.screenToRealFactor
                        + this.complexOrigin.re,
                (this.halfScreenHeight - y) * this.screenToRealFactor
                        + this.complexOrigin.im);
    }

    private void calculateScreenToRealFactor() {
        this.screenToRealFactor = this.realDimension
                / Math.min(this.screenWidth, this.screenHeight);
    }
}
