/*
 * GrayScaleColorizer
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

import java.awt.Color;

/**
 * The FireColorizer class provides a Colorizer that generates really hot
 * colors. 
 * 
 * @author both
 */
public final class FireColorizer implements Colorizer {
    private final int maxIterations;

    /**
     * Constructs a new FireColorizer.
     * 
     * @param maxIterations the maximum number of iterations of the associated
     *                      fractal generator
     */
    public FireColorizer(int maxIterations) {
        this.maxIterations = maxIterations;
    }

    /**
     * 
     * @param  numberOfIterations the given number of required iterations
     * @return the calculated Color
     * @see    Colorizer#calculateColor(int)
     */
    @Override
    public Color calculateColor(int numberOfIterations) {
	if (numberOfIterations == this.maxIterations) {
	    return Color.BLACK;
	}
        float hue = (float) numberOfIterations / this.maxIterations;
        float red = 0;
        float green = 0;
        float blue = 0;
        if (hue < .125) {
            red = 1;
            green = 1 - hue * 8;
        } else if(hue < .5) {
            blue = (hue - .125f) / .375f;
            red = 1 - blue;
        } else {
            blue = hue * 2 - 1;
        }
        return new Color(red, green, blue);
//        return new Color(hue, hue, 1 - hue);
    }
}
