/*
 * FractalGenerator
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

/**
 * The FractalGenerator interface provides a means of controlling the operation
 * of a fractal generator.
 * 
 * @author both
 */
public interface FractalGenerator {
    /**
     * Gets the complex point located at the center of the visible area of the
     * fractal.
     * 
     * @return the complex point located at the center of the visible area of
     *         the fractal
     */
    public Complex getComplexOrigin();

    /**
     * Sets the center of the visible part of the fractal to the specified
     * point on the complex plane.
     * 
     * @param complexOrigin the point on the complex plane about which to
     *                      center the visible part
     */
    public void setComplexOrigin(Complex complexOrigin);

    /**
     * Gets the minimum diameter of the visible part of the fractal.
     * 
     * @return the minimum diameter of the visible part of the fractal
     */
    public double getRealDimension();

    /**
     * Sets the minimum diameter of the visible part of the fractal to the
     * specified diameter.
     * 
     * @param realDimension the specified diameter
     */
    public void setRealDimension(double realDimension);

    /**
     * Gets the width of the area that is drawn in pixels.
     * 
     * @return the width of the area that is drawn in pixels
     */
    public int getScreenWidth();

    /**
     * Gets the height of the area that is drawn in pixels.
     * 
     * @return the height of the area that is drawn in pixels
     */
    public int getScreenHeight();

    /**
     * Sets the size of the area to be displayed in pixels.
     * 
     * @param width  the width of the area to be displayed in pixels
     * @param height the height of the area to be displayed in pixels
     */
    public void setScreenDimension(int width, int height);

    /**
     * Returns the number of required iterations to determine divergence of a
     * certain sequence at the specified pixel converted to a complex number.
     * 
     * @param  x the x coordinate of the specified pixel
     * @param  y the y coordinate of the specified pixel
     * @return the number of required iterations
     */
    public int getNumberOfIterationsAtPixel(int x, int y);

    /**
     * Calculates the point on the complex plane that corresponds to the given
     * pixel.
     * 
     * @param  x the x coordinate of the specified pixel
     * @param  y the y coordinate of the specified pixel
     * @return the point on the complex plane that corresponds to the given
     *         pixel
     */
    public Complex calculateComplexFromScreenCoordinates(int x, int y);
}
