/*
 * GrayScaleColorizer
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

import java.awt.Color;

/**
 * The GrayScaleColorizer class provides a Colorizer that generates different
 * shades of gray. 
 * 
 * @author both
 */
public final class GrayScaleColorizer implements Colorizer {
    private final int maxIterations;

    /**
     * Constructs a new GrayScaleColorizer.
     * 
     * @param maxIterations the maximum number of iterations of the associated
     *                      fractal generator
     */
    public GrayScaleColorizer(int maxIterations) {
        this.maxIterations = maxIterations;
    }

    /**
     * Calculates a shade of gray from the given number of required iterations
     * at a point in a fractal and the maximum number of iterations given to
     * the constructor.
     * 
     * @param  numberOfIterations the given number of required iterations
     * @return the calculated Color
     * @see    Colorizer#calculateColor(int)
     */
    @Override
    public Color calculateColor(int numberOfIterations) {
        float result = (float) numberOfIterations / this.maxIterations;
        return new Color(result, result, result);
    }
}
