/*
 * SimpleDoublePrecisionMandelbrotGenerator
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

/**
 * The SimpleDoublePrecisionMandelbrotGenerator provides an implementation for
 * calculating the number of required iterations to determine the divergence of
 * the sequence of points obtained by the recursion
 * z<sub>1</sub> := 1, z<sub>n + 1</sub> = (z<sub>n</sub>)<sup>2</sup> + c
 * where c is a point determined by screen coordinates.  This implementation
 * operates with standard double precision arithmetic.
 * 
 * @author both
 */
public class SimpleDoublePrecisionMandelbrotGenerator
        extends DoublePrecisionFractalGenerator {
    private int maxIterations;

    /**
     * Constructs a new SimpleDoublePrecisionMandelbrotGenerator.
     * 
     * @param maxIterations the maximum number of iterations to use
     */
    public SimpleDoublePrecisionMandelbrotGenerator(int maxIterations) {
        this.maxIterations = maxIterations;
    }

    /**
     * Calculates the number of required iterations to determine the divergence
     * of the sequence of points obtained by the recursion
     * z<sub>1</sub> := 1, z<sub>n + 1</sub> = (z<sub>n</sub>)<sup>2</sup> + c
     * where c is the result of the conversion of the specified pixel to a
     * complex number.
     * 
     * @param  x the x coordinate of the specified pixel
     * @param  y the y coordinate of the specified pixel
     * @return the number of required iterations
     * @see    FractalGenerator#getNumberOfIterationsAtPixel(int, int)
     */
    @Override
    public int getNumberOfIterationsAtPixel(int x, int y) {
        Complex c = calculateComplexFromScreenCoordinates(x, y);
        Complex z = new Complex(c);
        int i;
        for (i = 0; i < this.maxIterations && z.getAbsSquare() <= 4; ++i) {
            z.square();
            z.addTo(c);
        }
        return i;
    }
}
