/*
 * GrayScaleColorizer
 * 
 * Version 0.2alpha
 * 
 * 2010-06-11
 * 
 * CopyLeft
 */
package infpp.fractal;

import java.awt.Color;

/**
 * The YellowBlueColorizer class provides a Colorizer that generates colors
 * from yellow to blue. 
 * 
 * @author both
 */
public final class YellowBlueColorizer implements Colorizer {
    private final int maxIterations;

    /**
     * Constructs a new YellowBlueColorizer.
     * 
     * @param maxIterations the maximum number of iterations of the associated
     *                      fractal generator
     */
    public YellowBlueColorizer(int maxIterations) {
        this.maxIterations = maxIterations;
    }

    /**
     * 
     * @param  numberOfIterations the given number of required iterations
     * @return the calculated Color
     * @see    Colorizer#calculateColor(int)
     */
    @Override
    public Color calculateColor(int numberOfIterations) {
	if (numberOfIterations == this.maxIterations) {
	    return Color.BLACK;
	}
        float hue = (float) numberOfIterations / this.maxIterations;
        float red = 0;
        float green = 0;
        float blue = 0;
        if (hue < .5) {
            blue = hue * 2;
        } else if(hue < .875) {
            red = (hue - .5f) / .375f;
            blue = 1 - red;
        } else {
            red = 1;
            green = (hue - .875f) * 8;
        }
        return new Color(red, green, blue);
    }
}
